Usage Reference for :mod:`pyvisfile.xdmf`
=========================================

This implementation targets XDMF3 and takes available fields directly from the
code in the `xdmf library <https://gitlab.kitware.com/xdmf/xdmf>`__. Additional
documentation can be found `online <https://www.xdmf.org/index.php/XDMF_Model_and_Format>`__,
but (at the time of this writing, December 2020) does not appear to be kept up to date.

.. automodule:: pyvisfile.xdmf
